@@ -1,5 +1,6 @@
 #pragma once
 #include <xs/xs.h>
+#include <xs/lib.h>
 #include <panda/time.h>
 #include <panda/date.h>
 
@@ -15,17 +16,19 @@ namespace xs { namespace date {
 
 using namespace panda::time;
 using namespace panda::date;
+using std::string_view;
+using xs::lib::sv2string_view;
 
 static const char* DATE_CLASS    = "Panda::Date";
 static const char* DATEREL_CLASS = "Panda::Date::Rel";
 static const char* DATEINT_CLASS = "Panda::Date::Int";
 
-inline const tz* tzget_required (pTHX_ SV* zone) {
-    return (zone && SvOK(zone)) ? tzget(SvPV_nolen(zone)) : tzlocal();
+inline const Timezone* tzget_required (pTHX_ SV* zone) {
+    return tzget(zone != NULL && SvOK(zone) ? sv2string_view(zone) : string_view());
 }
 
-inline const tz* tzget_optional (pTHX_ SV* zone) {
-    return zone ? (SvOK(zone) ? tzget(SvPV_nolen(zone)) : tzlocal()) : NULL;
+inline const Timezone* tzget_optional (pTHX_ SV* zone) {
+    return zone ? tzget(SvOK(zone) ? sv2string_view(zone) : string_view()) : NULL;
 }
 
 inline void daterel_chkro (pTHX_ const DateRel* THIS) {
