@@ -36,7 +36,7 @@
 
 namespace xs { namespace date {
 
-Date* SV2C_DATE_FUNC (pTHX_ SV* arg, const tz* zone, Date* operand) {
+Date* SV2C_DATE_FUNC (pTHX_ SV* arg, const Timezone* zone, Date* operand) {
     ptime_t epoch = 0;
     
     if (SvOK(arg)) {
